"""Exceptions module."""


class MorphToolException(Exception):
    """MorphTool exception."""


class NoAxonException(MorphToolException):
    """MorphTool exception."""


class NoDendriteException(MorphToolException):
    """MorphTool exception."""
